# securities-exchange


[![image](https://img.shields.io/pypi/v/securities-exchange.svg)](https://pypi.python.org/pypi/securities-exchange)

**A toy example of a Security Exchange in Python**

-   Free software: MIT License
-   Documentation: https://ggnne.github.io/securities-exchange


## Credits

This package was created with Cookiecutter and the `opengeos/cookiecutter-pypackage` project template.

- Cookiecutter: [https://github.com/audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
- `opengeos/cookiecutter-pypackage`: [https://github.com/opengeos/cookiecutter-pypackage](https://github.com/opengeos/cookiecutter-pypackage)
